============
Contributors
============

`Jon Guyer`_
    is a member of the research staff of |MSED| in
    |MML| at |NIST|.  Jon's computational interests are in object-oriented
    design and in phase field modeling of electrochemistry.

`Daniel Wheeler`_
    is a guest researcher in |MSED| in
    |MML| at |NIST|.  Daniel's interests are in numerical modeling, finite
    volume techniques, and level set treatments.

`Jim Warren`_
    is the leader of the Thermodynamics and Kinetics group in
    |MSED| and Director of |CTCMS| of |MML| at
    |NIST|. Jim is interested in a variety of problems, including the
    phase field modeling of solidification, polycrystalline solids,
    and the electrochemical interface.

Alex Mont
    developed the :term:`PyxViewer` and the :term:`Gmsh` import and export
    modules while he was a student at `Montgomery Blair High School`_.

Katie Travis
    developed the automated
    :option:`--inline` optimization code for ``Variable`` objects
    while she was a SURF_ student from `Smith College`_.

Max Gibiansky
    added support for the :ref:`TRILINOS` solvers while he was a SURF_ student
    from `Harvey Mudd College`_

`Andrew Reeve`_
    added support for anisotropic diffusion coefficients while he was on
    sabbatical from the `University of Maine`_.

Olivia Buzek
    worked on adding :ref:`TRILINOS` parallel computations while she was a SURF_ student
    from the `University of Maryland`_

Daniel Stiles
    worked on adding :ref:`TRILINOS` parallel computations while he was
    a student at `Montgomery Blair High School`_.

James O'Beirne
    added full mesh partitioning using :term:`Gmsh`. James also greatly
    improved the :term:`Gmsh`-:term:`FiPy` pipeline. Other contributions
    include updating :term:`FiPy` to use properties pervasively,
    deployment of a `Buildbot <https://buildbot.net/>`_ server to automate :term:`FiPy`
    testing and a full refactor of the ``Mesh`` classes.

.. |MSED| replace:: the `Materials Science and Engineering Division`_
.. |MML| replace:: the `Material Measurement Laboratory`_
.. |CTCMS| replace:: the `Center for Theoretical and Computational Materials Science`_
.. |NIST| replace:: the `National Institute of Standards and Technology`_

.. _Material Measurement Laboratory:                               http://www.nist.gov/mml/
.. _Center for Theoretical and Computational Materials Science:    http://www.ctcms.nist.gov/
.. _Materials Science and Engineering Division:                    http://www.nist.gov/mml/msed/
.. _National Institute of Standards and Technology:                http://www.nist.gov/
.. _SURF:                                                          http://www.surf.nist.gov/surf2.htm

.. _Montgomery Blair High School:                                  http://www.mbhs.edu/
.. _Smith College:                                                 http://www.smith.edu/
.. _Harvey Mudd College:                                           http://www.hmc.edu/
.. _University of Maine:
.. _University of Maryland:                                        http://www.maryland.edu/

.. _Jon Guyer:      http://www.nist.gov/cgi-bin/wwwph/cso.nist.gov?Query=Jonathan+Guyer
.. _Daniel Wheeler: http://www.nist.gov/cgi-bin/wwwph/cso.nist.gov?Query=Daniel+Wheeler
.. _Jim Warren:     http://www.ctcms.nist.gov/~jwarren/
.. _Andrew Reeve:   http://www.geology.um.maine.edu/HTML-ERS/People/PeopleFSAndyReeve.htm
